Crate range_tree_rs

Crate range_tree_rs 

This crate provides a range-tree implementation, intended to manage range section with btree.

Structs

Cursor
A read-only cursor for navigating through entries in a BTreeMap.
DummyOps
IntoIter
An owning iterator over the entries of a BTreeMap Uses PathCache to manage tree traversal and safe deallocation
Iter
An iterator over the entries of a BTreeMap
RangeIter
RangeTree

Traits

RangeTreeKey
RangeTreeOps
Trait for allocator