Crate range_tree_rs

Crate range_tree_rs 

This crate provides a range-tree implementation, intended to manage range section with btree.

Structs

IntoIter
consuming iterator of RangeTree An owning iterator over the entries of a BTreeMap Uses PathCache to manage tree traversal and safe deallocation
Iter
Iterator of RangeTree (without bound) An iterator over the entries of a BTreeMap
RangeIter
An iterator with bound, acquire from RangeTree::range()
RangeTree
A b+tree stores range segment of [start, start+size)

Traits

RangeTreeKey
RangeTreeOps
Trait for allocator